Learn R Programming

SlimR (version 1.1.1)

.compute_weighted_scores: Compute weighted scores for per-cell annotation

Description

This function uses an improved weighting scheme that considers:

  1. Expression level (log-normalized)

  2. Detection rate (binary: above min_expression threshold)

  3. Marker specificity (how unique is this marker to this cell type)

  4. Expression variability (CV-based: more variable genes are more discriminative)

Usage

.compute_weighted_scores(expr_matrix, marker_sets, min_expression)

Arguments