A dataset containing marker genes for different Macrophage subtypes from the article "Macrophage diversity in cancer revisited in the era of single-cell omics"
Markers_list_PCTAMA list with 7 tables.
This list is a table of 7 types of Tumor-associated macrophages (TAMs) markers obtained from the article "Macrophage diversity in cancer revisited in the era of single-cell omics". The data source is "https://doi.org/10.1016/j.it.2022.04.008", and the reference literature is: Ruo-Yu Ma et al. (2022) doi:10.1016/j.it.2022.04.008.
Other Section_0_Database:
Cellmarker2,
Cellmarker2_raw,
Cellmarker2_table,
Markers_list_PCTIT,
Markers_list_TCellSI,
Markers_list_scIBD,
PanglaoDB,
PanglaoDB_raw,
PanglaoDB_table