Learn R Programming

SlimR (version 1.1.1)

PanglaoDB: PanglaoDB dataset

Description

A dataset containing marker genes for different cell types from PanglaoDB

Usage

PanglaoDB

Arguments

Format

A data frame with 9 columns:

Details

This dataset is used to filter and create a standardized marker list.'

See Also

Other Section_0_Database: Cellmarker2, Cellmarker2_raw, Cellmarker2_table, Markers_list_PCTAM, Markers_list_PCTIT, Markers_list_TCellSI, Markers_list_scIBD, PanglaoDB_raw, PanglaoDB_table