powered by
A dataset containing marker genes for different cell types from PanglaoDB
PanglaoDB_raw
A data frame with 14 columns contined in the PanglaoDB database:
This dataset is used to filter and create a standardized marker list.'
Other Section_0_Database: Cellmarker2, Cellmarker2_raw, Cellmarker2_table, Markers_list_PCTAM, Markers_list_PCTIT, Markers_list_TCellSI, Markers_list_scIBD, PanglaoDB, PanglaoDB_table
Cellmarker2
Cellmarker2_raw
Cellmarker2_table
Markers_list_PCTAM
Markers_list_PCTIT
Markers_list_TCellSI
Markers_list_scIBD
PanglaoDB
PanglaoDB_table