| ScType | R Documentation |
A processed long-format dataset containing marker genes for different cell types from the ScType database. Each row represents one marker gene for a given tissue type and cell type.
ScType
A tibble with 3 columns:
Tissue type (e.g., "Immune system", "Brain", "Liver")
Cell type name, formatted as "cellName(shortName)" when a short name is available, or "cellName" otherwise
Gene symbol of the marker
This dataset is used to filter and create a standardized marker list.
The dataset can be filtered based on tissue type and cell name to generate
a list of marker genes for specific cell types using
Markers_filter_ScType.
https://github.com/IanevskiAleksandr/sc-type
Other Section_0_Database:
Cellmarker2,
Cellmarker2_raw,
Cellmarker2_table,
Markers_list_PCTAM,
Markers_list_PCTIT,
Markers_list_TCellSI,
Markers_list_scIBD,
PanglaoDB,
PanglaoDB_raw,
PanglaoDB_table,
ScType_raw,
ScType_table
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.